==> veil-fabric-1.21-1.0.0.19-sources.jar: foundry/veil/api/client/tooltip/Tooltippable.java <==
package foundry.veil.api.client.tooltip;

import foundry.veil.api.client.color.ColorTheme;
import foundry.veil.api.client.tooltip.anim.TooltipTimeline;
import foundry.veil.impl.client.render.VeilUITooltipRenderer;
import java.util.List;
import net.minecraft.class_1799;
import net.minecraft.class_2487;
import net.minecraft.class_2561;

/**
 * Interface for components that can have a tooltip displayed when hovered over in-world
 *
 * @author amo
 * @see VeilUITooltipRenderer
 * @since 1.0.0
 * @deprecated Use component instead
 */
@Deprecated
public interface Tooltippable {

    /**
     * Get the tooltip components from the block entity
     *
     * @return the tooltip components
     */
    List<class_2561> getTooltip();

    boolean isTooltipEnabled();

    class_2487 saveTooltipData();

    void loadTooltipData(class_2487 tag);

    /**
     * Set the tooltip components for the block entity
     *
     * @param tooltip the tooltip components to set
     */
    void setTooltip(List<class_2561> tooltip);

    /**
     * Add a tooltip component to the block entity
     *
     * @param tooltip
     */
    void addTooltip(class_2561 tooltip);

    /**
     * Add a list of tooltip components to the block entity
     *
     * @param tooltip
     */
    void addTooltip(List<class_2561> tooltip);

    /**
     * Add a tooltip component to the block entity
     *
     * @param tooltip
     */
    void addTooltip(String tooltip);

    /**
     * Get the theme object for the tooltip from the block entity
     *
     * @return the theme object
     * @see ColorTheme
     */
    ColorTheme getTheme();

    /**
     * Set the theme object for the tooltip from the block entity
     *
     * @param theme the theme object to set
     */
    void setTheme(ColorTheme theme);

    /**
     * Set the background color of the theme
     *
     * @param color the color to set
     */
    void setBackgroundColor(int color);

    /**
     * Set the top border color of the theme
     *
     * @param color
     */
    void setTopBorderColor(int color);

    /**
     * Set the bottom border color of the theme
     *
     * @param color
     */
    void setBottomBorderColor(int color);

    /**
     * Whether the tooltip should be rendered in worldspace or not
     *
     * @return true if the tooltip should be rendered in worldspace, false if it should be rendered in screenspace
     */
    boolean getWorldspace();

    /**
     * Obtain the timeline for the tooltip
     *
     * @return the timeline
     */
    TooltipTimeline getTimeline();

    /**
     * The stack for the tooltip to take components from
     *
     * @return the stack
     */
    class_1799 getStack();

    /**
     * Increase the tooltip width
     *
     * @return the bonus width
     */
    int getTooltipWidth();

    /**
     * Increase the tooltip height
     *
     * @return the bonus height
     */
    int getTooltipHeight();

    /**
     * Get the x offset for the tooltip
     *
     * @return
     */
    int getTooltipXOffset();

    /**
     * Get the y offset for the tooltip
     *
     * @return
     */
    int getTooltipYOffset();

    /**
     * Get the items to render in the tooltip and data about them
     *
     * @return the items
     */
    List<VeilUIItemTooltipDataHolder> getItems();

}

==> veil-fabric-1.21.1-1.0.0.242-sources.jar: foundry/veil/api/client/tooltip/Tooltippable.java <==
package foundry.veil.api.client.tooltip;

import foundry.veil.api.client.color.ColorTheme;
import foundry.veil.impl.client.render.VeilUITooltipRenderer;
import java.util.List;
import net.minecraft.class_1799;
import net.minecraft.class_2487;
import net.minecraft.class_2561;

/**
 * Interface for components that can have a tooltip displayed when hovered over in-world
 *
 * @author amo
 * @see VeilUITooltipRenderer
 * @since 1.0.0
 */
@Deprecated
public interface Tooltippable {

    /**
     * Get the tooltip components from the block entity
     *
     * @return the tooltip components
     */
    List<class_2561> getTooltip();

    default boolean isTooltipEnabled() {
        return true;
    }

    default class_2487 saveTooltipData() {
        return new class_2487();
    }

    default void loadTooltipData(class_2487 tag) {
    }

    /**
     * Set the tooltip components for the block entity
     *
     * @param tooltip the tooltip components to set
     */
    default void setTooltip(List<class_2561> tooltip) {        
    }

    /**
     * Add a tooltip component to the block entity
     *
     * @param tooltip
     */
    default void addTooltip(class_2561 tooltip) {
    }

    /**
     * Add a list of tooltip components to the block entity
     *
     * @param tooltip
     */
    default void addTooltip(List<class_2561> tooltip) {
    }

    /**
     * Add a tooltip component to the block entity
     *
     * @param tooltip
     */
    default void addTooltip(String tooltip) {
    }

    /**
     * Get the theme object for the tooltip from the block entity
     *
     * @return the theme object
     * @see ColorTheme
     */
    default ColorTheme getTheme() {
        return ColorTheme.DEFAULT;
    }

    /**
     * Set the theme object for the tooltip from the block entity
     *
     * @param theme the theme object to set
     */
    default void setTheme(ColorTheme theme) {
    }

    /**
     * Set the background color of the theme
     *
     * @param color the color to set
     */
    default void setBackgroundColor(int color) {
    }

    /**
     * Set the top border color of the theme
     *
     * @param color
     */
    default void setTopBorderColor(int color) {
    }

    /**
     * Set the bottom border color of the theme
     *
     * @param color
     */
    default void setBottomBorderColor(int color) {
    }

    /**
     * Whether the tooltip should be rendered in worldspace or not
     *
     * @return true if the tooltip should be rendered in worldspace, false if it should be rendered in screenspace
     */
    default boolean getWorldspace() {
        return false;
    }

    /**
     * The stack for the tooltip to take components from
     *
     * @return the stack
     */
    default class_1799 getStack() {
        return null;
    }

    /**
     * Increase the tooltip width
     *
     * @return the bonus width
     */
    default int getTooltipWidth() {
        return 0;
    }

    /**
     * Increase the tooltip height
     *
     * @return the bonus height
     */
    default int getTooltipHeight() {
        return 0;
    }

    /**
     * Get the x offset for the tooltip
     *
     * @return
     */
    default int getTooltipXOffset() {
        return 0;
    }

    /**
     * Get the y offset for the tooltip
     *
     * @return
     */
    default int getTooltipYOffset() {
        return 0;
    }

    /**
     * Get the items to render in the tooltip and data about them
     *
     * @return the items
     */
    default List<VeilUIItemTooltipDataHolder> getItems() {
        return List.of();
    }

}
